summaryrefslogtreecommitdiffstats
path: root/lib/kofficeui/KoPageLayoutDia.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /lib/kofficeui/KoPageLayoutDia.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kofficeui/KoPageLayoutDia.h')
-rw-r--r--lib/kofficeui/KoPageLayoutDia.h70
1 files changed, 36 insertions, 34 deletions
diff --git a/lib/kofficeui/KoPageLayoutDia.h b/lib/kofficeui/KoPageLayoutDia.h
index f3f1d932..05f8f3db 100644
--- a/lib/kofficeui/KoPageLayoutDia.h
+++ b/lib/kofficeui/KoPageLayoutDia.h
@@ -22,16 +22,16 @@
#ifndef __KOPGLAYOUTDIA_H__
#define __KOPGLAYOUTDIA_H__
-#include <qgroupbox.h>
+#include <tqgroupbox.h>
#include <KoGlobal.h>
#include <KoUnit.h>
#include <kdialogbase.h>
#include <KoPageLayout.h>
-class QButtonGroup;
-class QComboBox;
-class QLineEdit;
-class QCheckBox;
+class TQButtonGroup;
+class TQComboBox;
+class TQLineEdit;
+class TQCheckBox;
class KoUnitDoubleSpinBox;
class KoPageLayoutColumns;
class KoPageLayoutSize;
@@ -44,23 +44,24 @@ enum { FORMAT_AND_BORDERS = 1, HEADER_AND_FOOTER = 2, COLUMNS = 4, DISABLE_BORDE
* KoPagePreview.
* Internal to KoPageLayoutDia.
*/
-class KoPagePreview : public QGroupBox
+class KoPagePreview : public TQGroupBox
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* constructor
*/
- KoPagePreview( QWidget*, const char*, const KoPageLayout & );
+ KoPagePreview( TQWidget*, const char*, const KoPageLayout & );
/**
* destructor
*/
~KoPagePreview();
/**
* set page layout
*/
void setPageLayout( const KoPageLayout& );
void setPageColumns( const KoColumns& );
@@ -68,7 +69,7 @@ public:
protected:
// paint page
- void drawContents( QPainter* );
+ void drawContents( TQPainter* );
double m_pageHeight, m_pageWidth, m_textFrameX, m_textFrameY, m_textFrameWidth, m_textFrameHeight;
int columns;
@@ -77,44 +78,45 @@ protected:
class KoPageLayoutDiaPrivate;
/**
* With this dialog the user can specify the layout of the paper during printing.
*/
class KOFFICEUI_EXPORT KoPageLayoutDia : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor.
*
* @param parent The parent of the dialog.
* @param name The name of the dialog.
* @param layout The layout.
* @param headfoot The header and the footer.
* @param flags a variable with all features this dialog should show.
* @param unit The unit to use for displaying the values to the user.
* @param modal Whether the dialog is modal or not.
*/
- KoPageLayoutDia( QWidget* parent, const char* name,
- const KoPageLayout& layout,
+ KoPageLayoutDia( TQWidget* tqparent, const char* name,
+ const KoPageLayout& tqlayout,
const KoHeadFoot& headfoot,
int flags, KoUnit::Unit unit, bool modal=true );
/**
* Constructor.
*
* @param parent The parent of the dialog.
* @param name The name of the dialog.
* @param layout The layout.
* @param headfoot The header and the footer.
* @param columns The number of columns on the page.
* @param kwheadfoot The KWord header and footer.
* @param tabs The number of tabs.
* @param unit The unit to use for displaying the values to the user
*/
- KoPageLayoutDia( QWidget* parent, const char* name,
- const KoPageLayout& layout,
+ KoPageLayoutDia( TQWidget* tqparent, const char* name,
+ const KoPageLayout& tqlayout,
const KoHeadFoot& headfoot,
const KoColumns& columns,
const KoKWHeaderFooter& kwheadfoot,
@@ -126,26 +128,26 @@ public:
~KoPageLayoutDia();
/**
* Show page layout dialog.
* See constructor for documentation on the parameters
*/
- static bool pageLayout( KoPageLayout&, KoHeadFoot&, int tabs, KoUnit::Unit& unit, QWidget* parent = 0 );
+ static bool pageLayout( KoPageLayout&, KoHeadFoot&, int tabs, KoUnit::Unit& unit, TQWidget* tqparent = 0 );
/**
* Show page layout dialog.
* See constructor for documentation on the parameters
*/
- static bool pageLayout( KoPageLayout&, KoHeadFoot&, KoColumns&, KoKWHeaderFooter&, int tabs, KoUnit::Unit& unit, QWidget* parent = 0 );
+ static bool pageLayout( KoPageLayout&, KoHeadFoot&, KoColumns&, KoKWHeaderFooter&, int tabs, KoUnit::Unit& unit, TQWidget* tqparent = 0 );
/**
* Retrieves a standard page layout.
* Deprecated: better use KoPageLayout::standardLayout()
*/
static KDE_DEPRECATED KoPageLayout standardLayout();
/**
- * Returns the layout
+ * Returns the tqlayout
*/
- const KoPageLayout& layout() const { return m_layout; }
+ const KoPageLayout& tqlayout() const { return m_layout; }
/**
* Returns the header and footer information
@@ -168,14 +170,14 @@ private:
void setupTab4( const KoKWHeaderFooter kwhf );
// dialog objects
- QLineEdit *eHeadLeft;
- QLineEdit *eHeadMid;
- QLineEdit *eHeadRight;
- QLineEdit *eFootLeft;
- QLineEdit *eFootMid;
- QLineEdit *eFootRight;
-
- // layout
+ TQLineEdit *eHeadLeft;
+ TQLineEdit *eHeadMid;
+ TQLineEdit *eHeadRight;
+ TQLineEdit *eFootLeft;
+ TQLineEdit *eFootMid;
+ TQLineEdit *eFootRight;
+
+ // tqlayout
KoPageLayout m_layout;
KoColumns m_column;
@@ -187,7 +189,7 @@ protected slots:
virtual void slotOk();
private slots:
- void sizeUpdated(KoPageLayout &layout);
+ void sizeUpdated(KoPageLayout &tqlayout);
void columnsUpdated(KoColumns &columns);
private:
@@ -44,23 +44,24 @@ enum { FORMAT_AND_BORDERS = 1, HEADER_AND_FOOTER = 2, COLUMNS = 4, DISABLE_BORDE
~KoPagePreview();
/**
- * set page layout
+ * set page tqlayout
*/
void setPageLayout( const KoPageLayout& );
@@ -77,44 +78,45 @@ protected:
class KoPageLayoutDiaPrivate;
/**
- * With this dialog the user can specify the layout of the paper during printing.
+ * With this dialog the user can specify the tqlayout of the paper during printing.
*/
class KOFFICEUI_EXPORT KoPageLayoutDia : public KDialogBase
@@ -77,44 +78,45 @@ protected:
* Constructor.
*
- * @param parent The parent of the dialog.
+ * @param tqparent The tqparent of the dialog.
* @param name The name of the dialog.
@@ -77,44 +78,45 @@ protected:
* @param name The name of the dialog.
- * @param layout The layout.
+ * @param tqlayout The tqlayout.
* @param headfoot The header and the footer.
* @param flags a variable with all features this dialog should show.
@@ -77,44 +78,45 @@ protected:
* Constructor.
*
- * @param parent The parent of the dialog.
+ * @param tqparent The tqparent of the dialog.
* @param name The name of the dialog.
@@ -77,44 +78,45 @@ protected:
* @param name The name of the dialog.
- * @param layout The layout.
+ * @param tqlayout The tqlayout.
* @param headfoot The header and the footer.
* @param columns The number of columns on the page.
@@ -126,26 +128,26 @@ public:
~KoPageLayoutDia();
/**
- * Show page layout dialog.
+ * Show page tqlayout dialog.
* See constructor for documentation on the parameters
*/
@@ -126,26 +128,26 @@ public:
/**
- * Show page layout dialog.
+ * Show page tqlayout dialog.
* See constructor for documentation on the parameters
*/
@@ -126,26 +128,26 @@ public:
/**
- * Retrieves a standard page layout.
+ * Retrieves a standard page tqlayout.
* Deprecated: better use KoPageLayout::standardLayout()
*/